#
# spec file for package tinyobjloader
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2018-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 2
%define lname   libtinyobjloader%{sover}
Name:           tinyobjloader
Version:        2.0.0rc9
Release:        2.2
Summary:        Wavefront .obj file loader
License:        MIT
Group:          Development/Languages/C and C++
URL:            https://github.com/tinyobjloader/tinyobjloader
Source:         %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         tinyobjloader-fix-cmake-path.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
A single-file Wavefront .obj loader written in C++.
It can parse over 10M polygons with moderate memory and time.

%package -n %{lname}
Summary:        Wavefront .obj file loader
Group:          System/Libraries

%description -n %{lname}
A single-file Wavefront .obj loader written in C++.
It can parse over 10M polygons with moderate memory and time.

%package devel
Summary:        Development files for tinyobjloader
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
A single-file Wavefront .obj file loader written in C++.
No dependency except for C++ STL. It can parse over 10M polygons with
moderate memory and time.

This subpackage contains libraries and header files for developing
applications that want to make use of tinyobjloader.

%prep
%autosetup -p1

%build
%cmake \
    -DTINYOBJLOADER_COMPILATION_SHARED=ON
%make_jobs

%install
%cmake_install
rm -f %{buildroot}/%{_datadir}/doc/packages/tinyobjloader/LICENSE

%post   -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license LICENSE
%doc README.md
%{_libdir}/libtinyobjloader.so.%{sover}*

%files devel
%{_includedir}/tiny_obj_loader.h
%{_libdir}/libtinyobjloader.so
%{_libdir}/pkgconfig/tinyobjloader.pc
%{_libdir}/cmake/tinyobjloader-*.cmake

%changelog
* Mon Feb 26 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Fri May 20 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.0.0rc9
  * Latest release candidate
  * Minor documentation updates
* Mon Aug 23 2021 mardnh@gmx.de
- Update to version 2.0.0rc8+git.20210821:
  * Add new object oriented API. 1.x API is still provided.
  * Support line primitive.
  * Support points primitive.
  * Support multiple search path for .mtl(v1 API).
  * Support vertex weight `vw`(as an tinyobj extension)
  * Support escaped whitespece in mtllib
  * Add robust triangulation using Mapbox
    earcut(TINYOBJLOADER_USE_MAPBOX_EARCUT).
  * Fix CVE-2020-28589: tinyobjloader: An improper array index
    validation could lead to code execution.
* Mon Aug  6 2018 jengelh@inai.de
- Ensure neutrality of descriptions.
* Sat Aug  4 2018 mardnh@gmx.de
- Initial package, version 1.0.6
